==> thunder-8.x-2.32-no-core.tar.gz: thunder/README.md <==
# <img src="./files/images/thunder.svg?sanitize=true" alt="Thunder" width="4%"/> Thunder [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=I%20just%20tried%20ThunderCMS.%20The%20CMS%20for%20professional%20publishing!&url=https://www.thunder.org&via=ThunderCoreTeam&hashtags=drupal8,publishing,ThunderCMS)

[![Build Status](https://travis-ci.org/BurdaMagazinOrg/thunder-distribution.svg?branch=develop)](https://travis-ci.org/BurdaMagazinOrg/thunder-distribution)



Thunder is a Drupal 8 distribution for professional publishers. It consists of the current Drupal 8 functionality, lots of useful modules from publishers and industry partners, and an environment which makes it easy to install, deploy and add new functionality.

## Feature Highlights
### <img src="./files/images/story_fireplace_b.png" alt="Storytelling" width="2%"/> Storytelling
Create thrilling articles with multimedia content. It’s easy to enrich your article with pictures, video, and social media snippets and arrange everything as you like it.

![Storytelling](./files/images/storytelling.png)
### <img src="./files/images/media_handling_b_0.png" alt="Storytelling" width="2%"/> Media handling
Add pictures, galleries and videos to your article by just dragging and dropping everything right where you need it.
### <img src="./files/images/mobile_friendly_e_0.png" alt="Storytelling" width="2%"/> Mobile friendly
With Thunder, editors and administrators can work from any device – on the go, easy and fast. Users benefit from a modern and flexible front end.

![Mobile preview](./files/images/mobile.png)
### <img src="./files/images/schedule_content_g_0.png" alt="Storytelling" width="2%"/> Schedule content
Plan at which day and time articles should be published – and when they shouldn’t be visible to the public anymore.
### <img src="./files/images/flexible_system_b_0.png" alt="Storytelling" width="2%"/> Flexible system
Benefit from a wide range of additional functionality by industry partners or by one of more than 2,500 modules from the Drupal community.
### <img src="./files/images/drupal_community_b_1.png" alt="Storytelling" width="2%"/> Open Source
Using open source technology reduces development costs and resources and makes you part of the Drupal community with more than 100,000 users actively contributing.

*[More information about the modules used in Thunder](https://burdamagazinorg.github.io/thunder-documentation/modules)*
## Installation
**Highly recommended: Install Thunder with composer**

```
composer create-project burdamagazinorg/thunder-project thunder --no-interaction
```
For further information follow the [install instructions](https://www.drupal.org/docs/8/install).

If you don't want to use Composer, you can install Thunder the traditional way by downloading a tarball from our [drupal.org](https://www.drupal.org/project/thunder) project page.
## Contributing
If you want to help, to make Thunder even better, please take a look at the [contributing guidelines](CONTRIBUTING.md).

## Documentation
For more detailed information, please take a look at [https://burdamagazinorg.github.io/thunder-documentation/](https://burdamagazinorg.github.io/thunder-documentation/).

## Development
For information on the installation and development of Thunder, please take a look at [docs/development.md](docs/development.md).

==> thunder-8.x-2.38-no-core.tar.gz: thunder/README.md <==
# <img src="./files/images/thunder.svg?sanitize=true" alt="Thunder" width="4%"/> Thunder [![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=I%20just%20tried%20ThunderCMS.%20The%20CMS%20for%20professional%20publishing!&url=https://www.thunder.org&via=ThunderCoreTeam&hashtags=drupal8,publishing,ThunderCMS)

[![Build Status](https://travis-ci.org/BurdaMagazinOrg/thunder-distribution.svg?branch=8.x-2.x)](https://travis-ci.org/BurdaMagazinOrg/thunder-distribution)

Thunder is a Drupal 8 distribution for professional publishers. It consists of the current Drupal 8 functionality, lots of useful modules from publishers and industry partners, and an environment which makes it easy to install, deploy and add new functionality.


## Installing Thunder
Instructions on how to install Thunder can be found at the [installation guide](https://burdamagazinorg.github.io/thunder-documentation/docs#docs-install) and in the [Drupal documentation](https://www.drupal.org/docs/8/install)..

### Quick start installation
To start quickly, run this in your terminal to install Thunder from command line:

```
composer create-project burdamagazinorg/thunder-project thunder --no-interaction
cd thunder/docroot
php core/scripts/drupal quick-start thunder
```
For further information follow the [install instructions](https://www.drupal.org/docs/8/install/drupal-8-quick-start-command).

## Feature Highlights
### <img src="./files/images/story_fireplace_b.png" alt="Storytelling" width="2%"/> Storytelling
Create thrilling articles with multimedia content. It’s easy to enrich your article with pictures, video, and social media snippets and arrange everything as you like it.

![Storytelling](./files/images/storytelling.png)
### <img src="./files/images/media_handling_b_0.png" alt="Storytelling" width="2%"/> Media handling
Add pictures, galleries and videos to your article by just dragging and dropping everything right where you need it.
### <img src="./files/images/mobile_friendly_e_0.png" alt="Storytelling" width="2%"/> Mobile friendly
With Thunder, editors and administrators can work from any device – on the go, easy and fast. Users benefit from a modern and flexible front end.

![Mobile preview](./files/images/mobile.png)
### <img src="./files/images/schedule_content_g_0.png" alt="Storytelling" width="2%"/> Schedule content
Plan at which day and time articles should be published – and when they shouldn’t be visible to the public anymore.
### <img src="./files/images/flexible_system_b_0.png" alt="Storytelling" width="2%"/> Flexible system
Benefit from a wide range of additional functionality by industry partners or by one of more than 2,500 modules from the Drupal community.
### <img src="./files/images/drupal_community_b_1.png" alt="Storytelling" width="2%"/> Open Source
Using open source technology reduces development costs and resources and makes you part of the Drupal community with more than 100,000 users actively contributing.

*[More information about the modules used in Thunder](https://burdamagazinorg.github.io/thunder-documentation/modules)*

## Support
For general help using Thunder, please refer to [the official Thunder documentation](https://burdamagazinorg.github.io/thunder-documentation).

### Community support
For additional help, you can use one of this channel to ask question:

* [Slack](https://thunder.org/contact-us) (highly recommended for faster support)
* [Twitter](https://twitter.com/ThunderCoreTeam)
* [Facebook](https://www.facebook.com/Thunder-CMS-168018513979183/).

## Contributing
If you want to help, to make Thunder even better, please take a look at the [contributing guidelines](CONTRIBUTING.md).

## Development
For information on the installation and development of Thunder, please take a look at [docs/development.md](docs/development.md).
